@@ -68,6 +68,11 @@ pub enum Command {
         #[structopt(subcommand)]
         snapshot_subcommands: SnapshotSubcommands,
     },
+    /// Withdraw
+    Withdraw {
+        #[structopt(subcommand)]
+        withdraw_subcommands: WithdrawSubcommands,
+    },
 }
 
 #[derive(Debug, StructOpt)]
@@ -369,3 +374,17 @@ pub enum UpdateSubcommands {
         json_file: String,
     },
 }
+
+#[derive(Debug, StructOpt)]
+pub enum WithdrawSubcommands {
+    /// Withdraw funds from a candy machine v2
+    #[structopt(name = "cm-v2")]
+    CMV2 {
+        /// Candy Machine V2 ID
+        candy_machine_id: String,
+
+        /// Path to the creator's keypair file
+        #[structopt(short, long)]
+        keypair: String,
+    },
+}
